@@ -6,6 +6,7 @@ from volsite_postgres_common.db.BFn import BFn
 from volsite_postgres_common.db.CFn import CFn
 from volworld_common.test.Timer import Timer
 from volsite_postgres_common.test.db.ATestDb import ATestDb
+from volworld_common.util.json import print_json_by_attributes
 
 
 def json_fn(fn: str, input_j: dict, conn, attList,
@@ -35,26 +36,26 @@ def json_fn(fn: str, input_j: dict, conn, attList,
         print('</code>')
     return output
 
-def convert_json_by_attributes(j, attList) -> str:
-    abb_att = {}
+# def convert_json_by_attributes(j, attList) -> str:
+#     abb_att = {}
+#
+#     for a in attList:
+#         for name in a.__dict__:
+#             abb = a.__dict__[name]
+#             abb_att[f"\"{abb}\":"] = f"\"{abb}__{name}\":"
+#
+#     res = json.dumps(j, indent=4, sort_keys=True)
+#     for att in abb_att.keys():
+#         res = res.replace(att, abb_att[att])
+#
+#     return res
 
-    for a in attList:
-        for name in a.__dict__:
-            abb = a.__dict__[name]
-            abb_att[f"\"{abb}\":"] = f"\"{abb}__{name}\":"
-
-    res = json.dumps(j, indent=4, sort_keys=True)
-    for att in abb_att.keys():
-        res = res.replace(att, abb_att[att])
-
-    return res
-
-def print_json_by_attributes(j, attList, print_long_att: bool = False):
-    if not print_long_att:
-        print(json.dumps(j, indent=4, sort_keys=True))
-        return
-
-    print(convert_json_by_attributes(j, attList))
+# def print_json_by_attributes(j, attList, print_long_att: bool = False):
+#     if not print_long_att:
+#         print(json.dumps(j, indent=4, sort_keys=True))
+#         return
+#
+#     print(convert_json_by_attributes(j, attList))
 
 
 def json_fn_db(
